# Human Organ Atlas Python Tools

This package contains tools for working with data from the [Human Organ Atlas](https://human-organ-atlas.esrf.eu).

## Getting started

A few useful places to start:

- The [tutorial](tutorial/index.md) contains a step by step guide to using `hoa-tools`
- [How do I...?](how_to.md) lists how to do common tasks with `hoa-tools`
- The [API reference](api/index.md) contains a listing of classes and functions in `hoa-tools`

## Feedback

Suggestions and bug reports are very welcome, and encouraged! Please [open an issue](https://github.com/HumanOrganAtlas/hoa-tools/issues/new) on our GitHub issue tracker.

## Contributing

Contributions are very welcome, and encouraged! Please open a pull request with your suggested change on our [GitHub repository](https://github.com/HumanOrganAtlas/hoa-tools).
